@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATIONBUTTONGROUP_H
-#define KDECORATION2_DECORATIONBUTTONGROUP_H
+#pragma once
 #include "decorationbutton.h"
 #include <functional>
 #include <kdecoration2/kdecoration2_export.h>
@@ -70,7 +69,7 @@ public:
      **/
     virtual void paint(QPainter *painter, const QRect &repaintArea);
 
-    QPointer<Decoration> decoration() const;
+    Decoration *decoration() const;
 
     qreal spacing() const;
     void setSpacing(qreal spacing);
@@ -83,12 +82,12 @@ public:
      * Adds @p button to the DecorationButtonGroup and triggers a re-layout of all
      * DecorationButtons.
      **/
-    void addButton(const QPointer<DecorationButton> &button);
+    void addButton(DecorationButton *button);
     /**
      * Removes @p button from the DecorationButtonGroup and triggers a re-layout of all
      * DecorationButtons.
      **/
-    void removeButton(const QPointer<DecorationButton> &button);
+    void removeButton(DecorationButton *button);
     /**
      * Removes all DecorationButtons with @p type from the DecorationButtonGroup and
      * triggers a re-layout of all DecorationButtons.
@@ -101,7 +100,7 @@ public:
     /**
      * @returns All DecorationButtons in this DecorationButtonGroup
      **/
-    QVector<QPointer<DecorationButton>> buttons() const;
+    QList<DecorationButton *> buttons() const;
 
 Q_SIGNALS:
     void spacingChanged(qreal);
@@ -110,9 +109,7 @@ Q_SIGNALS:
 
 private:
     class Private;
-    QScopedPointer<Private> d;
+    std::unique_ptr<Private> d;
 };
 
 } // namespace
-
-#endif
